/**
 * Copyright (c) Jupyter Development Team.
 * Distributed under the terms of the Modified BSD License.
 */

/* Dashboard container */
.jupyter-dashboard[data-dashboard-layout="report"] #notebook-container {
    padding-left: 0;
    padding-right: 0;
    transition: background-color 0.75s,
                box-shadow 0.75s;
}
.jupyter-dashboard[data-dashboard-layout="report"]:not(.view-only) #notebook-container:hover {
    background-color: transparent;
    box-shadow: none;
}

/* Dashboard cell */
.jupyter-dashboard[data-dashboard-layout="report"] .cell {
    background-color: white;
    margin-bottom: 1em;
}
.jupyter-dashboard[data-dashboard-layout="report"]:not(.view-only) .cell {
    min-height: 5em;
}
.jupyter-dashboard[data-dashboard-layout="report"] .cell.dashboard-hidden {
    height: 5em;
    overflow: hidden;
}

/* Hidden cells */
.jupyter-dashboard[data-dashboard-layout="report"] .dashboard-report-collapse-btn {
    background-color: #f8f8f8;
    color: #b2b2b2;
    cursor: pointer;
    font-variant: small-caps;
    height: 2em;
    line-height: 1.8em;
    margin-bottom: 1em;
    text-align: center;
}
.jupyter-dashboard[data-dashboard-layout="report"] .dashboard-report-collapse-btn:hover {
    background-color: #f6f6f6;
}
.jupyter-dashboard[data-dashboard-layout="report"] .dashboard-report-collapse-btn .dashboard-report-hidden-count {
    font-size: smaller;
}
.jupyter-dashboard[data-dashboard-layout="report"] .cell.dashboard-hidden {
    border-top: 1px solid #eee;
}
.jupyter-dashboard[data-dashboard-layout="report"] .dashboard-report-collapse-btn:not(.dashboard-collapsed) .dashboard-report-expand-label,
.jupyter-dashboard[data-dashboard-layout="report"] .dashboard-report-collapse-btn.dashboard-collapsed .dashboard-report-collapse-label,
.jupyter-dashboard[data-dashboard-layout="report"] .dashboard-report-collapse-btn .dashboard-report-collapse-text[data-cell-count="1"] .plural-s,
.jupyter-dashboard[data-dashboard-layout="report"].view-only .dashboard-report-collapse-btn,
.jupyter-dashboard[data-dashboard-layout="report"].view-only .cell.dashboard-hidden {
    display: none;
}
.jupyter-dashboard[data-dashboard-layout="report"] .cell.dashboard-collapsed {
    display: none;
}
.jupyter-dashboard[data-dashboard-layout="report"] .dashboard-report-collapse-btn:not(.dashboard-collapsed),
.jupyter-dashboard[data-dashboard-layout="report"] .cell.dashboard-hidden {
    margin-bottom: 0;
}
.jupyter-dashboard[data-dashboard-layout="report"] .cell.dashboard-hidden,
.jupyter-dashboard[data-dashboard-layout="report"] .cell.dashboard-hidden .cell-control-container {
    background-color: #f8f8f8;
}
.jupyter-dashboard[data-dashboard-layout="report"] .cell.dashboard-hidden:not(.dashboard-collapsed) + .cell:not(.dashboard-hidden) {
    margin-top: 1em;
}
.jupyter-dashboard[data-dashboard-layout="report"] .cell .cell-control-se {
    border: none;
    padding-right: 1em;
    visibility: visible;
}

 /* Hide specific cell controls based on hidden state */
.jupyter-dashboard[data-dashboard-layout="report"] .cell:not(.dashboard-hidden) .cell-control.add-btn,
.jupyter-dashboard[data-dashboard-layout="report"] .cell.dashboard-hidden .cell-control.hide-btn,
.jupyter-dashboard[data-dashboard-layout="report"] .cell:not(.dashboard-hidden) .cell-control-se {
    display: none;
}
