/**
 * Copyright (c) Jupyter Development Team.
 * Distributed under the terms of the Modified BSD License.
 */

.jupyter-dashboard .container div.output_wrapper {
    z-index: auto; /* override `z-index:1` set by Notebook */
}

.jupyter-dashboard .container div.output_subarea {
    max-width: 100%; /* override Notebook CSS so it takes up full width */
    overflow: hidden; /* hide overflowing contents */
}

/* disable display of paragraph anchor text*/
.jupyter-dashboard .container h1 .anchor-link,
.jupyter-dashboard .container h2 .anchor-link,
.jupyter-dashboard .container h3 .anchor-link,
.jupyter-dashboard .container h4 .anchor-link,
.jupyter-dashboard .container h5 .anchor-link,
.jupyter-dashboard .container h6 .anchor-link {
    display: none;
}
